package VMOMI::HostFileSystemVolumeFileSystemType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
